@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10926 2018-03-26 07:30:32Z Kevin $
+# $Id: __init__.py 10999 2018-04-30 07:30:23Z Lavender $
 #
-# Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
+# Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
 # Licensed under the Proprietary License,
 # you may not use this file except in compliance with the License.
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Kevin $ (last)
-# $Date: 2018-03-26 15:30:32 +0800 (週一, 26 三月 2018) $
-# $Revision: 10926 $
+# $Author: Lavender $ (last)
+# $Date: 2018-04-30 15:30:23 +0800 (週一, 30 四月 2018) $
+# $Revision: 10999 $
 
 import os
 import sys
@@ -32,6 +32,81 @@ from oscar import OSCAR_MAIN_TEMPLATE_DIR
 
 from django.utils.translation import ugettext_lazy as _
 
+CKEDITOR_CONFIGS = {
+    'default': {
+        'skin': 'moono',
+        # 'skin': 'office2013',
+        'toolbar_Basic': [
+            ['Source', '-', 'Bold', 'Italic']
+        ],
+        'toolbar_YourCustomToolbarConfig': [
+            {'name': 'document', 'items': [
+                'Source', '-', 'Save', 'NewPage', 
+                'Preview', 'Print', '-', 'Templates']},
+            {'name': 'clipboard', 'items': [
+                'Cut', 'Copy', 'Paste', 'PasteText', 
+                'PasteFromWord', '-', 'Undo', 'Redo']},
+            {'name': 'editing', 'items': ['Find', 'Replace', '-', 'SelectAll']},
+            {'name': 'forms',
+             'items': ['Form', 'Checkbox', 'Radio', 'TextField', 
+                       'Textarea', 'Select', 'Button', 'ImageButton',
+                       'HiddenField']},
+            '/',
+            {'name': 'basicstyles',
+             'items': ['Bold', 'Italic', 'Underline', 'Strike', 
+                       'Subscript', 'Superscript', '-', 'RemoveFormat']},
+            {'name': 'paragraph',
+             'items': ['NumberedList', 'BulletedList', '-', 'Outdent', 
+                       'Indent', '-', 'Blockquote', 'CreateDiv', '-',
+                       'JustifyLeft', 'JustifyCenter', 'JustifyRight', 
+                       'JustifyBlock', '-', 'BidiLtr', 'BidiRtl',
+                       'Language']},
+            {'name': 'links', 'items': ['Link', 'Unlink', 'Anchor']},
+            {'name': 'insert',
+             'items': ['Image', 'Flash', 'Table', 'HorizontalRule', 
+                       'Smiley', 'SpecialChar', 'PageBreak', 'Iframe']},
+            '/',
+            {'name': 'styles', 'items': [
+                'Styles', 'Format', 'Font', 'FontSize']},
+            {'name': 'colors', 'items': ['TextColor', 'BGColor']},
+            {'name': 'tools', 'items': ['Maximize', 'ShowBlocks']},
+            {'name': 'about', 'items': ['About']},
+            '/',  # put this to force next toolbar on new line
+            {'name': 'yourcustomtools', 'items': [
+                # put the name of your editor.ui.addButton here
+                'Preview',
+                'Maximize',
+
+            ]},
+        ],
+        'toolbar': 'YourCustomToolbarConfig',  # put selected toolbar config here
+        # 'toolbarGroups': [{ 'name': 'document', 'groups': [ 'mode', 'document', 'doctools' ] }],
+        # 'height': 291,
+        # 'width': '100%',
+        # 'filebrowserWindowHeight': 725,
+        # 'filebrowserWindowWidth': 940,
+        # 'toolbarCanCollapse': True,
+        # 'mathJaxLib': '//cdn.mathjax.org/mathjax/2.2-latest/MathJax.js?config=TeX-AMS_HTML',
+        'tabSpaces': 4,
+        'extraPlugins': ','.join([
+            'uploadimage', # the upload image feature
+            # your extra plugins here
+            'div',
+            'autolink',
+            'autoembed',
+            'embedsemantic',
+            'autogrow',
+            # 'devtools',
+            'widget',
+            'lineutils',
+            'clipboard',
+            'dialog',
+            'dialogui',
+            'elementspath'
+        ]),
+    }
+}
+
 def attachSettings(settingsDict, enablePaypal=False):
     """
     Attach default settings to settings.py.
@@ -53,6 +128,9 @@ def attachSettings(settingsDict, enablePaypal=False):
         'django.contrib.sites',
         'django.contrib.flatpages',
         'widget_tweaks',
+        'Iuno.shop',
+        'ckeditor',
+        'ckeditor_uploader',
     ) + tuple(get_core_apps(extraApps))
     
     ADDING_MIDDLEWARE_CLASSES = (
@@ -157,7 +235,7 @@ def attachSettings(settingsDict, enablePaypal=False):
     # see #2784
     addOscarDefaultsPackages = {}
     oscarDefaultsPackages = __import__(
-            'oscar.defaults', globals(), locals(), [], 0
+            'oscar.defaults', globals(), locals(), [], -1
         ).__dict__['defaults']
     for attr in dir(oscarDefaultsPackages):
         addOscarDefaultsPackages[attr] = getattr(
@@ -198,6 +276,15 @@ def attachSettings(settingsDict, enablePaypal=False):
         else:
             settingsDict['OSCAR_DASHBOARD_NAVIGATION'] = ADDING_OSCAR_DASHBOARD_NAVIGATION
     #=========================================================================
+    
+    #=========================================================================
+    # Django ckeditor settings
+    DJANGO_CKEDITOR_CONF = {
+        'CKEDITOR_UPLOAD_PATH': "uploads/",
+        'CKEDITOR_CONFIGS': CKEDITOR_CONFIGS,
+    }
+    update(settingsDict, DJANGO_CKEDITOR_CONF)
+    #=========================================================================
 
 
 def attachShopURLs(settings, urlpatterns):
