@@ -215,3 +215,41 @@ class TestAttachSettings(TestCase):
         
         self.assertEqual(settingsContent['TEMPLATES'],
                          templatesSettings['TEMPLATES'])
+
+    def testHttpsSettings(self):
+        settingsContent = TestAttachSettings.REQUIRED_SETTINGS.copy()
+
+        # Test if we specify SECURE_PROXY_SSL_HEADER in settings.py, 
+        # it should follow the settings value.
+
+        settingsContentForHTTP = settingsContent.copy()
+        settingsContentForHTTP['SECURE_PROXY_SSL_HEADER'] = (
+                                            'HTTP_X_FORWARDED_PROTO', 'http')
+        attachSettings(settingsContentForHTTP)
+
+        httpSettings = {
+            'SECURE_PROXY_SSL_HEADER': ('HTTP_X_FORWARDED_PROTO', 'http'),
+        }
+
+        self.assertEqual(settingsContentForHTTP['SECURE_PROXY_SSL_HEADER'],
+                         httpSettings['SECURE_PROXY_SSL_HEADER'])
+
+        # Test if we set HTTPS=on in env, it should set  HTTP_X_FORWARDED_PROTO
+        # to https if we didn't specify the value in settings.py, otherwise, it 
+        # it should follow the value in settings.py.
+
+        os.environ["HTTPS"] = "on"
+        settingsContentForHTTPS = settingsContent.copy()
+
+        attachSettings(settingsContentForHTTP)
+        attachSettings(settingsContentForHTTPS)
+
+        httpsSettings = {
+            'SECURE_PROXY_SSL_HEADER': ('HTTP_X_FORWARDED_PROTO', 'https'),
+        }
+
+        self.assertEqual(settingsContentForHTTPS['SECURE_PROXY_SSL_HEADER'],
+                    httpsSettings['SECURE_PROXY_SSL_HEADER'])
+
+        self.assertEqual(settingsContentForHTTP['SECURE_PROXY_SSL_HEADER'],
+                         httpSettings['SECURE_PROXY_SSL_HEADER'])
\ No newline at end of file
